GlassShape.concentric constructor
const
GlassShape.concentric()
Radius inherited from the enclosing container so corners stay concentric.
Implementation
const factory GlassShape.concentric() = _ConcentricShape;
Radius inherited from the enclosing container so corners stay concentric.
const factory GlassShape.concentric() = _ConcentricShape;