warmUp static method

Future<FragmentProgram?> warmUp()

Warms the shader so the first glass surface does not pay compilation cost on a visible frame.

Implementation

static Future<ui.FragmentProgram?> warmUp() {
  if (_program != null) return Future<ui.FragmentProgram?>.value(_program);
  return _pending ??= _load();
}