child property
Content composited above the material. Also what sizes the surface: the shader region is measured from the child, not from incoming constraints.
Implementation
final Widget child;
Content composited above the material. Also what sizes the surface: the shader region is measured from the child, not from incoming constraints.
final Widget child;